@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2005 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.44.2.10 2005/05/17 00:40:41 vapier Exp $
+# $Header$
 
 # Common functions
 [[ ${RC_GOT_FUNCTIONS} != "yes" ]] && source /sbin/functions.sh
@@ -45,7 +45,7 @@ fi
 # has completed
 if [[ ${NETSERVICE} == "yes" && ${IFACE} != "lo" ]] ; then
 	if [[ -z ${mylevel} || ${mylevel} == ${BOOTLEVEL} ]] ; then
-		eerror "$0: cannot start until the runlevel "${BOOTLEVEL}" has completed"
+		eerror "${myservice}: cannot start until the runlevel ${BOOTLEVEL} has completed"
 		exit 1
 	fi
 fi
